@@ -281,9 +281,11 @@ sf_types <- c ("points", "lines", "polygons", "multilines", "multipolygons")
 #' }
 osmdata_sf <- function(q, doc, quiet=TRUE, stringsAsFactors = FALSE) {
     obj <- osmdata () # uses class def
-    if (missing (q) & !quiet)
-        message ('q missing: osmdata object will not include query')
-    else if (is (q, 'overpass_query'))
+    if (missing (q))
+    {
+        if (!quiet)
+            message ('q missing: osmdata object will not include query')
+    } else if (is (q, 'overpass_query'))
     {
         obj$bbox <- q$bbox
         obj$overpass_call <- opq_string (q)
@@ -320,9 +322,12 @@ fill_objects <- function (res, obj, type = "points",
     obj_name <- paste0 ("osm_", type)
     kv_name <- paste0 (type, "_kv")
     if (length (res [[kv_name]]) > 0)
+    {
+        if (!stringsAsFactors)
+            res [[kv_name]] [] <- lapply (res [[kv_name]], as.character)
         obj [[obj_name]] <- make_sf (geometry, res [[kv_name]],
                                      stringsAsFactors = stringsAsFactors)
-    else if (length (obj [[obj_name]]) > 0)
+    } else if (length (obj [[obj_name]]) > 0)
         obj [[obj_name]] <- make_sf (geometry,
                                      stringsAsFactors = stringsAsFactors)
 
